@@ -3,15 +3,14 @@ package PadWalker;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-#require Exporter;
 require DynaLoader;
 
 require 5.006;
 
 @ISA = qw(Exporter DynaLoader);
-@EXPORT_OK = qw(peek_my);
+@EXPORT_OK = qw(peek_my peek_sub);
 
-$VERSION = '0.03';
+$VERSION = '0.05';
 
 bootstrap PadWalker $VERSION;
 
@@ -27,7 +26,7 @@ PadWalker - walk pads
 
 =head1 SYNOPSIS
 
-  use PadWalker qw(peek_my);
+  use PadWalker qw(peek_my peek_sub);
   ...
 
 =head1 DESCRIPTION
@@ -59,10 +58,17 @@ Or a more complex example:
   increment_my_x;
   print $x;  # prints 6
 
+The C<peek_sub> routine takes a coderef as its argument, and returns a hash
+of the lexical variables used in that sub.
+
 =head1 AUTHOR
 
 Robin Houston <robin@kitsite.com>
 
+With contributions from Richard Soberberg.
+
+=back
+
 =head1 SEE ALSO
 
 perl(1).
